=== modified file 'include/drizzle_com.h'
--- include/drizzle_com.h	2008-07-09 12:31:20 +0000
+++ include/drizzle_com.h	2008-07-09 15:52:52 +0000
@@ -271,7 +271,8 @@
 
 #define packet_error (~(unsigned long) 0)
 
-enum enum_field_types { MYSQL_TYPE_DECIMAL, MYSQL_TYPE_TINY,
+/* Start TINY at 1 because we removed DECIMAL from off the front of the enum */
+enum enum_field_types { MYSQL_TYPE_TINY=1,
 			MYSQL_TYPE_SHORT,  MYSQL_TYPE_LONG,
 			MYSQL_TYPE_FLOAT,  MYSQL_TYPE_DOUBLE,
 			MYSQL_TYPE_NULL,   MYSQL_TYPE_TIMESTAMP,

=== modified file 'include/mysql/plugin.h'
--- include/mysql/plugin.h	2008-07-06 13:01:13 +0000
+++ include/mysql/plugin.h	2008-07-09 15:52:52 +0000
@@ -126,6 +126,9 @@
 #define SHOW_VAR_FUNC_BUFF_SIZE 1024
 typedef int (*mysql_show_var_func)(MYSQL_THD, struct st_mysql_show_var*, char *);
 
+struct st_show_var_func_container {
+  mysql_show_var_func func;
+};
 /*
   declarations for server variables and command line options
 */

=== modified file 'sql/drizzled.cc'
--- sql/drizzled.cc	2008-07-09 13:07:14 +0000
+++ sql/drizzled.cc	2008-07-09 15:52:52 +0000
@@ -1784,7 +1784,7 @@
   return(0);					/* purecov: deadcode */
 }
 
-static void check_data_home(const char *path)
+static void check_data_home(const char *path __attribute__((__unused__)))
 {}
 
 #endif	/* __WIN__*/
@@ -4053,13 +4053,18 @@
   {0, 0, 0, 0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0}
 };
 
-static int show_net_compression(THD *thd, SHOW_VAR *var, char *buff)
+static int show_net_compression(THD *thd __attribute__((__unused__)),
+                                SHOW_VAR *var,
+                                char *buff __attribute__((__unused__)))
 {
   var->type= SHOW_MY_BOOL;
   var->value= (char *)&thd->net.compress;
   return 0;
 }
 
+static st_show_var_func_container
+show_net_compression_cont= { &show_net_compression };
+
 static int show_starttime(THD *thd, SHOW_VAR *var, char *buff)
 {
   var->type= SHOW_LONG;
@@ -4068,6 +4073,9 @@
   return 0;
 }
 
+static st_show_var_func_container
+show_starttime_cont= { &show_starttime };
+
 static int show_flushstatustime(THD *thd, SHOW_VAR *var, char *buff)
 {
   var->type= SHOW_LONG;
@@ -4076,7 +4084,11 @@
   return 0;
 }
 
-static int show_slave_running(THD *thd, SHOW_VAR *var, char *buff)
+static st_show_var_func_container
+show_flushstatustime_cont= { &show_flushstatustime };
+
+static int show_slave_running(THD *thd __attribute__((__unused__)),
+                              SHOW_VAR *var, char *buff)
 {
   var->type= SHOW_MY_BOOL;
   pthread_mutex_lock(&LOCK_active_mi);
@@ -4087,7 +4099,11 @@
   return 0;
 }
 
-static int show_slave_retried_trans(THD *thd, SHOW_VAR *var, char *buff)
+static st_show_var_func_container
+show_slave_running_cont= { &show_slave_running };
+
+static int show_slave_retried_trans(THD *thd __attribute__((__unused__)),
+                                    SHOW_VAR *var, char *buff)
 {
   /*
     TODO: with multimaster, have one such counter per line in
@@ -4108,7 +4124,11 @@
   return 0;
 }
 
-static int show_slave_received_heartbeats(THD *thd, SHOW_VAR *var, char *buff)
+static st_show_var_func_container
+show_slave_retried_trans_cont= { &show_slave_retried_trans };
+
+static int show_slave_received_heartbeats(THD *thd __attribute__((__unused__)),
+                                          SHOW_VAR *var, char *buff)
 {
   pthread_mutex_lock(&LOCK_active_mi);
   if (active_mi)
@@ -4125,7 +4145,11 @@
   return 0;
 }
 
-static int show_heartbeat_period(THD *thd, SHOW_VAR *var, char *buff)
+static st_show_var_func_container
+show_slave_received_heartbeats_cont= { &show_slave_received_heartbeats };
+
+static int show_heartbeat_period(THD *thd __attribute__((__unused__)),
+                                 SHOW_VAR *var, char *buff)
 {
   pthread_mutex_lock(&LOCK_active_mi);
   if (active_mi)
@@ -4140,8 +4164,11 @@
   return 0;
 }
 
+static st_show_var_func_container
+show_heartbeat_period_cont= { &show_heartbeat_period};
 
-static int show_open_tables(THD *thd, SHOW_VAR *var, char *buff)
+static int show_open_tables(THD *thd __attribute__((__unused__)),
+                            SHOW_VAR *var, char *buff)
 {
   var->type= SHOW_LONG;
   var->value= buff;
@@ -4149,7 +4176,8 @@
   return 0;
 }
 
-static int show_table_definitions(THD *thd, SHOW_VAR *var, char *buff)
+static int show_table_definitions(THD *thd __attribute__((__unused__)),
+                                  SHOW_VAR *var, char *buff)
 {
   var->type= SHOW_LONG;
   var->value= buff;
@@ -4157,6 +4185,11 @@
   return 0;
 }
 
+static st_show_var_func_container
+show_open_tables_cont= { &show_open_tables };
+static st_show_var_func_container
+show_table_definitions_cont= { &show_table_definitions };
+
 /*
   Variables shown by SHOW STATUS in alphabetical order
 */
@@ -4169,7 +4202,7 @@
   {"Bytes_received",           (char*) offsetof(STATUS_VAR, bytes_received), SHOW_LONGLONG_STATUS},
   {"Bytes_sent",               (char*) offsetof(STATUS_VAR, bytes_sent), SHOW_LONGLONG_STATUS},
   {"Com",                      (char*) com_status_vars, SHOW_ARRAY},
-  {"Compression",              (char*) &show_net_compression, SHOW_FUNC},
+  {"Compression",              (char*) &show_net_compression_cont, SHOW_FUNC},
   {"Connections",              (char*) &thread_id,              SHOW_LONG_NOFLUSH},
   {"Created_tmp_disk_tables",  (char*) offsetof(STATUS_VAR, created_tmp_disk_tables), SHOW_LONG_STATUS},
   {"Created_tmp_files",	       (char*) &my_tmp_file_created,	SHOW_LONG},
@@ -4201,8 +4234,8 @@
   {"Max_used_connections",     (char*) &max_used_connections,  SHOW_LONG},
   {"Open_files",               (char*) &my_file_opened,         SHOW_LONG_NOFLUSH},
   {"Open_streams",             (char*) &my_stream_opened,       SHOW_LONG_NOFLUSH},
-  {"Open_table_definitions",   (char*) &show_table_definitions, SHOW_FUNC},
-  {"Open_tables",              (char*) &show_open_tables,       SHOW_FUNC},
+  {"Open_table_definitions",   (char*) &show_table_definitions_cont, SHOW_FUNC},
+  {"Open_tables",              (char*) &show_open_tables_cont,       SHOW_FUNC},
   {"Opened_files",             (char*) &my_file_total_opened, SHOW_LONG_NOFLUSH},
   {"Opened_tables",            (char*) offsetof(STATUS_VAR, opened_tables), SHOW_LONG_STATUS},
   {"Opened_table_definitions", (char*) offsetof(STATUS_VAR, opened_shares), SHOW_LONG_STATUS},
@@ -4213,10 +4246,10 @@
   {"Select_range_check",       (char*) offsetof(STATUS_VAR, select_range_check_count), SHOW_LONG_STATUS},
   {"Select_scan",	       (char*) offsetof(STATUS_VAR, select_scan_count), SHOW_LONG_STATUS},
   {"Slave_open_temp_tables",   (char*) &slave_open_temp_tables, SHOW_LONG},
-  {"Slave_retried_transactions",(char*) &show_slave_retried_trans, SHOW_FUNC},
-  {"Slave_heartbeat_period",   (char*) &show_heartbeat_period, SHOW_FUNC},
-  {"Slave_received_heartbeats",(char*) &show_slave_received_heartbeats, SHOW_FUNC},
-  {"Slave_running",            (char*) &show_slave_running,     SHOW_FUNC},
+  {"Slave_retried_transactions",(char*) &show_slave_retried_trans_cont, SHOW_FUNC},
+  {"Slave_heartbeat_period",   (char*) &show_heartbeat_period_cont, SHOW_FUNC},
+  {"Slave_received_heartbeats",(char*) &show_slave_received_heartbeats_cont, SHOW_FUNC},
+  {"Slave_running",            (char*) &show_slave_running_cont,     SHOW_FUNC},
   {"Slow_launch_threads",      (char*) &slow_launch_threads,    SHOW_LONG},
   {"Slow_queries",             (char*) offsetof(STATUS_VAR, long_query_count), SHOW_LONG_STATUS},
   {"Sort_merge_passes",	       (char*) offsetof(STATUS_VAR, filesort_merge_passes), SHOW_LONG_STATUS},
@@ -4234,8 +4267,8 @@
   {"Threads_connected",        (char*) &connection_count,       SHOW_INT},
   {"Threads_created",	       (char*) &thread_created,		SHOW_LONG_NOFLUSH},
   {"Threads_running",          (char*) &thread_running,         SHOW_INT},
-  {"Uptime",                   (char*) &show_starttime,         SHOW_FUNC},
-  {"Uptime_since_flush_status",(char*) &show_flushstatustime,   SHOW_FUNC},
+  {"Uptime",                   (char*) &show_starttime_cont,         SHOW_FUNC},
+  {"Uptime_since_flush_status",(char*) &show_flushstatustime_cont,   SHOW_FUNC},
   {NullS, NullS, SHOW_LONG}
 };
 

=== modified file 'sql/field.cc'
--- sql/field.cc	2008-07-08 20:52:20 +0000
+++ sql/field.cc	2008-07-09 15:52:52 +0000
@@ -85,7 +85,7 @@
   //MYSQL_TYPE_NULL         MYSQL_TYPE_TIMESTAMP
     MYSQL_TYPE_NEWDECIMAL,  MYSQL_TYPE_VARCHAR,
   //MYSQL_TYPE_LONGLONG     MYSQL_TYPE_INT24
-    MYSQL_TYPE_DECIMAL,     MYSQL_TYPE_DECIMAL,
+  //MYSQL_TYPE_DECIMAL,     MYSQL_TYPE_DECIMAL,
   //MYSQL_TYPE_DATE         MYSQL_TYPE_TIME
     MYSQL_TYPE_VARCHAR,     MYSQL_TYPE_VARCHAR,
   //MYSQL_TYPE_DATETIME     MYSQL_TYPE_YEAR
@@ -454,7 +454,7 @@
   /* MYSQL_TYPE_YEAR -> */
   {
   //MYSQL_TYPE_DECIMAL      MYSQL_TYPE_TINY
-    MYSQL_TYPE_DECIMAL,     MYSQL_TYPE_TINY,
+    MYSQL_TYPE_NEWDECIMAL,  MYSQL_TYPE_TINY,
   //MYSQL_TYPE_SHORT        MYSQL_TYPE_LONG
     MYSQL_TYPE_SHORT,       MYSQL_TYPE_LONG,
   //MYSQL_TYPE_FLOAT        MYSQL_TYPE_DOUBLE
@@ -1385,7 +1385,7 @@
 }
 
 
-my_decimal *Field::val_decimal(my_decimal *decimal)
+my_decimal *Field::val_decimal(my_decimal *decimal __attribute__((__unused__)))
 {
   /* This never have to be called */
   DBUG_ASSERT(0);
@@ -1635,7 +1635,8 @@
     Needs to be changed if/when we want to support different time formats.
 */
 
-int Field::store_time(MYSQL_TIME *ltime, timestamp_type type_arg)
+int Field::store_time(MYSQL_TIME *ltime,
+                      timestamp_type type_arg __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   char buff[MAX_DATE_STRING_REP_LENGTH];
@@ -1960,7 +1961,8 @@
 }
 
 
-int Field_new_decimal::store_time(MYSQL_TIME *ltime, timestamp_type t_type)
+int Field_new_decimal::store_time(MYSQL_TIME *ltime,
+                                  timestamp_type t_type __attribute__((__unused__)))
 {
     my_decimal decimal_value;
     return store_value(date2my_decimal(ltime, &decimal_value));
@@ -3862,12 +3864,13 @@
   exception is different behavior of old/new timestamps during ALTER TABLE.
  */
 
-Field_timestamp::Field_timestamp(uchar *ptr_arg, uint32 len_arg,
+Field_timestamp::Field_timestamp(uchar *ptr_arg,
+                                 uint32 len_arg __attribute__((__unused__)),
                                  uchar *null_ptr_arg, uchar null_bit_arg,
-				 enum utype unireg_check_arg,
-				 const char *field_name_arg,
-				 TABLE_SHARE *share,
-				 CHARSET_INFO *cs)
+                                 enum utype unireg_check_arg,
+                                 const char *field_name_arg,
+                                 TABLE_SHARE *share,
+                                 CHARSET_INFO *cs)
   :Field_str(ptr_arg, MAX_DATETIME_WIDTH, null_ptr_arg, null_bit_arg,
 	     unireg_check_arg, field_name_arg, cs)
 {
@@ -3933,7 +3936,9 @@
 }
 
 
-int Field_timestamp::store(const char *from,uint len,CHARSET_INFO *cs)
+int Field_timestamp::store(const char *from,
+                           uint len,
+                           CHARSET_INFO *cs __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   MYSQL_TIME l_time;
@@ -3993,7 +3998,8 @@
 }
 
 
-int Field_timestamp::store(longlong nr, bool unsigned_val)
+int Field_timestamp::store(longlong nr,
+                           bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   MYSQL_TIME l_time;
@@ -4240,7 +4246,9 @@
 ** Stored as a 3 byte unsigned int
 ****************************************************************************/
 
-int Field_time::store(const char *from,uint len,CHARSET_INFO *cs)
+int Field_time::store(const char *from,
+                      uint len,
+                      CHARSET_INFO *cs __attribute__((__unused__)))
 {
   MYSQL_TIME ltime;
   long tmp;
@@ -4282,7 +4290,8 @@
 }
 
 
-int Field_time::store_time(MYSQL_TIME *ltime, timestamp_type time_type)
+int Field_time::store_time(MYSQL_TIME *ltime,
+                           timestamp_type time_type __attribute__((__unused__)))
 {
   long tmp= ((ltime->month ? 0 : ltime->day * 24L) + ltime->hour) * 10000L +
             (ltime->minute * 100 + ltime->second);
@@ -4549,7 +4558,8 @@
 }
 
 
-int Field_year::store(longlong nr, bool unsigned_val)
+int Field_year::store(longlong nr,
+                      bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   if (nr < 0 || (nr >= 100 && nr <= 1900) || nr > 2155)
@@ -4640,7 +4650,9 @@
        store function.
 */
 
-int Field_newdate::store(const char *from,uint len,CHARSET_INFO *cs)
+int Field_newdate::store(const char *from,
+                         uint len,
+                         CHARSET_INFO *cs __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   long tmp;
@@ -4690,7 +4702,8 @@
 }
 
 
-int Field_newdate::store(longlong nr, bool unsigned_val)
+int Field_newdate::store(longlong nr,
+                         bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   MYSQL_TIME l_time;
@@ -4872,7 +4885,9 @@
 ** Stored as a 8 byte unsigned int. Should sometimes be change to a 6 byte int.
 ****************************************************************************/
 
-int Field_datetime::store(const char *from,uint len,CHARSET_INFO *cs)
+int Field_datetime::store(const char *from,
+                          uint len,
+                          CHARSET_INFO *cs __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   MYSQL_TIME time_tmp;
@@ -4925,7 +4940,8 @@
 }
 
 
-int Field_datetime::store(longlong nr, bool unsigned_val)
+int Field_datetime::store(longlong nr,
+                          bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   MYSQL_TIME not_used;
@@ -5727,7 +5743,9 @@
 }
 
 
-uint Field_string::get_key_image(uchar *buff, uint length, imagetype type_arg)
+uint Field_string::get_key_image(uchar *buff,
+                                 uint length,
+                                 imagetype type_arg __attribute__((__unused__)))
 {
   uint bytes = my_charpos(field_charset, (char*) ptr,
                           (char*) ptr + field_length,
@@ -6084,7 +6102,8 @@
 */
 
 const uchar *
-Field_varstring::unpack_key(uchar *to, const uchar *key, uint max_length,
+Field_varstring::unpack_key(uchar *to __attribute__((__unused__)),
+                            const uchar *key, uint max_length,
                             bool low_byte_first __attribute__((unused)))
 {
   /* get length of the blob key */
@@ -6237,7 +6256,9 @@
   return (max_length > 255 ? 2 : 1)+max_length;
 }
 
-uint Field_varstring::get_key_image(uchar *buff, uint length, imagetype type)
+uint Field_varstring::get_key_image(uchar *buff,
+                                    uint length,
+                                    imagetype type __attribute__((__unused__)))
 {
   uint f_length=  length_bytes == 1 ? (uint) *ptr : uint2korr(ptr);
   uint local_char_length= length / field_charset->mbmaxlen;
@@ -6373,10 +6394,10 @@
 }
 
 
-void Field_blob::store_length(uchar *i_ptr, 
-                              uint i_packlength, 
-                              uint32 i_number, 
-                              bool low_byte_first)
+void Field_blob::store_length(uchar *i_ptr,
+                              uint i_packlength,
+                              uint32 i_number,
+                              bool low_byte_first __attribute__((__unused__)))
 {
   switch (i_packlength) {
   case 1:
@@ -6408,7 +6429,9 @@
 }
 
 
-uint32 Field_blob::get_length(const uchar *pos, uint packlength_arg, bool low_byte_first)
+uint32 Field_blob::get_length(const uchar *pos,
+                              uint packlength_arg,
+                              bool low_byte_first __attribute__((__unused__)))
 {
   switch (packlength_arg) {
   case 1:
@@ -6669,7 +6692,9 @@
 
 /* The following is used only when comparing a key */
 
-uint Field_blob::get_key_image(uchar *buff,uint length, imagetype type_arg)
+uint Field_blob::get_key_image(uchar *buff,
+                               uint length,
+                               imagetype type_arg __attribute__((__unused__)))
 {
   uint32 blob_length= get_length(ptr);
   uchar *blob;
@@ -6862,7 +6887,7 @@
 
    @return  New pointer into memory based on from + length of the data
 */
-const uchar *Field_blob::unpack(uchar *to, 
+const uchar *Field_blob::unpack(uchar *to __attribute__((__unused__)),
                                 const uchar *from,
                                 uint param_data,
                                 bool low_byte_first)
@@ -7151,7 +7176,8 @@
 }
 
 
-int Field_enum::store(longlong nr, bool unsigned_val)
+int Field_enum::store(longlong nr,
+                      bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   int error= 0;
@@ -7360,7 +7386,8 @@
 }
 
 
-int Field_set::store(longlong nr, bool unsigned_val)
+int Field_set::store(longlong nr,
+                     bool unsigned_val __attribute__((__unused__)))
 {
   ASSERT_COLUMN_MARKED_FOR_WRITE;
   int error= 0;
@@ -7581,14 +7608,15 @@
                         uint fld_type_modifier, Item *fld_default_value,
                         Item *fld_on_update_value, LEX_STRING *fld_comment,
                         char *fld_change, List<String> *fld_interval_list,
-                        CHARSET_INFO *fld_charset, uint fld_geom_type,
+                        CHARSET_INFO *fld_charset,
+                        uint fld_geom_type __attribute__((__unused__)),
                         enum column_format_type column_format)
 {
   uint sign_len, allowed_type_modifier= 0;
   ulong max_field_charlength= MAX_FIELD_CHARLENGTH;
 
   DBUG_ENTER("Create_field::init()");
-  
+
   field= 0;
   field_name= fld_name;
   def= fld_default_value;

=== modified file 'sql/lock.cc'
--- sql/lock.cc	2008-07-07 12:48:50 +0000
+++ sql/lock.cc	2008-07-09 15:52:52 +0000
@@ -131,7 +131,9 @@
   @param flags Lock flags
   @return 0 if all the check passed, non zero if a check failed.
 */
-int mysql_lock_tables_check(THD *thd, TABLE **tables, uint count, uint flags)
+int mysql_lock_tables_check(THD *thd __attribute__((__unused__)),
+                            TABLE **tables, uint count,
+                            uint flags __attribute__((__unused__)))
 {
   uint system_count;
   uint i;
@@ -1042,7 +1044,8 @@
 }
 
 
-void unlock_table_name(THD *thd, TABLE_LIST *table_list)
+void unlock_table_name(THD *thd __attribute__((__unused__)),
+                       TABLE_LIST *table_list)
 {
   if (table_list->table)
   {
@@ -1052,7 +1055,8 @@
 }
 
 
-static bool locked_named_table(THD *thd, TABLE_LIST *table_list)
+static bool locked_named_table(THD *thd __attribute__((__unused__)),
+                               TABLE_LIST *table_list)
 {
   for (; table_list ; table_list=table_list->next_local)
   {

=== modified file 'sql/log.cc'
--- sql/log.cc	2008-07-07 12:48:50 +0000
+++ sql/log.cc	2008-07-09 15:52:52 +0000
@@ -241,8 +241,11 @@
 
 
 /* Check if a given table is opened log table */
-int check_if_log_table(uint db_len, const char *db, uint table_name_len,
-                       const char *table_name, uint check_if_opened)
+int check_if_log_table(uint db_len __attribute__((__unused__)),
+                       const char *db __attribute__((__unused__)),
+                       uint table_name_len __attribute__((__unused__)),
+                       const char *table_name __attribute__((__unused__)),
+                       uint check_if_opened __attribute__((__unused__)))
 {
   return 0;
 }
@@ -284,11 +287,12 @@
 */
 
 bool Log_to_file_event_handler::
-  log_general(THD *thd, time_t event_time, const char *user_host,
+  log_general(THD *thd __attribute__((__unused__)),
+              time_t event_time, const char *user_host,
               uint user_host_len, int thread_id,
               const char *command_type, uint command_type_len,
               const char *sql_text, uint sql_text_len,
-              CHARSET_INFO *client_cs)
+              CHARSET_INFO *client_cs __attribute__((__unused__)))
 {
   return mysql_log.write(event_time, user_host, user_host_len,
                          thread_id, command_type, command_type_len,
@@ -400,7 +404,7 @@
 }
 
 
-bool LOGGER::flush_logs(THD *thd)
+bool LOGGER::flush_logs(THD *thd __attribute__((__unused__)))
 {
   int rc= 0;
 
@@ -611,7 +615,8 @@
 }
 
 
-bool LOGGER::activate_log_handler(THD* thd, uint log_type)
+bool LOGGER::activate_log_handler(THD* thd __attribute__((__unused__)),
+                                  uint log_type)
 {
   MYSQL_QUERY_LOG *file_log;
   bool res= FALSE;
@@ -645,7 +650,8 @@
 }
 
 
-void LOGGER::deactivate_log_handler(THD *thd, uint log_type)
+void LOGGER::deactivate_log_handler(THD *thd __attribute__((__unused__)),
+                                    uint log_type)
 {
   my_bool *tmp_opt= 0;
   MYSQL_LOG *file_log;
@@ -776,7 +782,8 @@
   return 0;
 }
 
-static int binlog_close_connection(handlerton *hton, THD *thd)
+static int binlog_close_connection(handlerton *hton __attribute__((__unused__)),
+                                   THD *thd)
 {
   binlog_trx_data *const trx_data=
     (binlog_trx_data*) thd_get_ha_data(thd, binlog_hton);
@@ -888,7 +895,9 @@
   DBUG_RETURN(error);
 }
 
-static int binlog_prepare(handlerton *hton, THD *thd, bool all)
+static int binlog_prepare(handlerton *hton __attribute__((__unused__)),
+                          THD *thd __attribute__((__unused__)),
+                          bool all __attribute__((__unused__)))
 {
   /*
     do nothing.
@@ -914,7 +923,8 @@
 
   @see handlerton::commit
 */
-static int binlog_commit(handlerton *hton, THD *thd, bool all)
+static int binlog_commit(handlerton *hton __attribute__((__unused__)),
+                         THD *thd, bool all)
 {
   DBUG_ENTER("binlog_commit");
   binlog_trx_data *const trx_data=
@@ -1019,7 +1029,8 @@
 
   @see handlerton::rollback
 */
-static int binlog_rollback(handlerton *hton, THD *thd, bool all)
+static int binlog_rollback(handlerton *hton __attribute__((__unused__)),
+                           THD *thd, bool all)
 {
   DBUG_ENTER("binlog_rollback");
   int error=0;
@@ -1088,7 +1099,8 @@
   that case there is no need to have it in the binlog).
 */
 
-static int binlog_savepoint_set(handlerton *hton, THD *thd, void *sv)
+static int binlog_savepoint_set(handlerton *hton __attribute__((__unused__)),
+                                THD *thd, void *sv)
 {
   DBUG_ENTER("binlog_savepoint_set");
 
@@ -1101,7 +1113,8 @@
   DBUG_RETURN(error);
 }
 
-static int binlog_savepoint_rollback(handlerton *hton, THD *thd, void *sv)
+static int binlog_savepoint_rollback(handlerton *hton __attribute__((__unused__)),
+                                     THD *thd, void *sv)
 {
   DBUG_ENTER("binlog_savepoint_rollback");
 
@@ -1491,8 +1504,10 @@
     TRUE - error occured
 */
 
-bool MYSQL_QUERY_LOG::write(time_t event_time, const char *user_host,
-                            uint user_host_len, int thread_id,
+bool MYSQL_QUERY_LOG::write(time_t event_time,
+                            const char *user_host __attribute__((__unused__)),
+                            uint user_host_len __attribute__((__unused__)),
+                            int thread_id,
                             const char *command_type, uint command_type_len,
                             const char *sql_text, uint sql_text_len)
 {
@@ -1592,7 +1607,8 @@
 */
 
 bool MYSQL_QUERY_LOG::write(THD *thd, time_t current_time,
-                            time_t query_start_arg, const char *user_host,
+                            time_t query_start_arg __attribute__((__unused__)),
+                            const char *user_host,
                             uint user_host_len, ulonglong query_utime,
                             ulonglong lock_utime, bool is_command,
                             const char *sql_text, uint sql_text_len)
@@ -3849,7 +3865,6 @@
     if (log_file.type == WRITE_CACHE && log_type == LOG_BIN)
     {
       my_off_t offset= BIN_LOG_HEADER_SIZE + FLAGS_OFFSET;
-      my_off_t org_position= my_tell(log_file.file, MYF(0));
       uchar flags= 0;            // clearing LOG_EVENT_BINLOG_IN_USE_F
       pwrite(log_file.file, &flags, 1, offset);
     }
@@ -4023,8 +4038,10 @@
     signature to be compatible with other logging routines, which could
     return an error (e.g. logging to the log tables)
 */
-static void print_buffer_to_file(enum loglevel level, int error_code,
-                                 const char *buffer, size_t buffer_length)
+static void print_buffer_to_file(enum loglevel level,
+                                 int error_code __attribute__((__unused__)),
+                                 const char *buffer,
+                                 size_t buffer_length __attribute__((__unused__)))
 {
   time_t skr;
   struct tm tm_tmp;
@@ -4359,7 +4376,7 @@
     to the position in memory where xid was logged to.
 */
 
-int TC_LOG_MMAP::log_xid(THD *thd, my_xid xid)
+int TC_LOG_MMAP::log_xid(THD *thd __attribute__((__unused__)), my_xid xid)
 {
   int err;
   PAGE *p;
@@ -4471,7 +4488,7 @@
   cookie points directly to the memory where xid was logged.
 */
 
-void TC_LOG_MMAP::unlog(ulong cookie, my_xid xid)
+void TC_LOG_MMAP::unlog(ulong cookie, my_xid xid __attribute__((__unused__)))
 {
   PAGE *p=pages+(cookie/tc_log_page_size);
   my_xid *x=(my_xid *)(data+cookie);
@@ -4730,7 +4747,8 @@
   DBUG_RETURN(!binlog_end_trans(thd, trx_data, &xle, TRUE));
 }
 
-void TC_LOG_BINLOG::unlog(ulong cookie, my_xid xid)
+void TC_LOG_BINLOG::unlog(ulong cookie __attribute__((__unused__)),
+                          my_xid xid __attribute__((__unused__)))
 {
   pthread_mutex_lock(&LOCK_prep_xids);
   DBUG_ASSERT(prepared_xids > 0);

=== modified file 'sql/log_event.cc'
--- sql/log_event.cc	2008-07-07 12:48:50 +0000
+++ sql/log_event.cc	2008-07-09 15:52:52 +0000
@@ -3113,7 +3113,7 @@
 }
 
 Log_event::enum_skip_reason
-Format_description_log_event::do_shall_skip(Relay_log_info *rli)
+Format_description_log_event::do_shall_skip(Relay_log_info *rli __attribute__((__unused__)))
 {
   return Log_event::EVENT_SKIP_NOT;
 }
@@ -4444,7 +4444,7 @@
 
 
 #if defined(HAVE_REPLICATION) && !defined(MYSQL_CLIENT)
-int Xid_log_event::do_apply_event(Relay_log_info const *rli)
+int Xid_log_event::do_apply_event(Relay_log_info const *rli __attribute__((__unused__)))
 {
   /* For a slave Xid_log_event is COMMIT */
   general_log_print(thd, COM_QUERY,
@@ -4997,7 +4997,7 @@
 
 
 #ifndef MYSQL_CLIENT
-int Slave_log_event::do_apply_event(Relay_log_info const *rli)
+int Slave_log_event::do_apply_event(Relay_log_info const *rli __attribute__((__unused__)))
 {
   if (mysql_bin_log.is_open())
     mysql_bin_log.write(this);
@@ -5563,7 +5563,7 @@
 */
 
 #if defined(HAVE_REPLICATION) && !defined(MYSQL_CLIENT)
-int Delete_file_log_event::do_apply_event(Relay_log_info const *rli)
+int Delete_file_log_event::do_apply_event(Relay_log_info const *rli __attribute__((__unused__)))
 {
   char fname[FN_REFLEN+10];
   char *ext= slave_load_file_stem(fname, file_id, server_id, ".data");
@@ -7019,7 +7019,8 @@
  */
 #if !defined(MYSQL_CLIENT)
 Table_map_log_event::Table_map_log_event(THD *thd, TABLE *tbl, ulong tid,
-                                         bool is_transactional, uint16 flags)
+                                         bool is_transactional __attribute__((__unused__)),
+                                         uint16 flags)
   : Log_event(thd, 0, true),
     m_table(tbl),
     m_dbnam(tbl->s->db.str),

=== modified file 'sql/rpl_record.cc'
--- sql/rpl_record.cc	2008-07-03 03:16:39 +0000
+++ sql/rpl_record.cc	2008-07-09 15:52:52 +0000
@@ -326,9 +326,11 @@
 
   @retval 0                       Success
   @retval ER_NO_DEFAULT_FOR_FIELD Default value could not be set for a field
- */ 
-int prepare_record(TABLE *const table, 
-                   const MY_BITMAP *cols, uint width, const bool check)
+*/
+int prepare_record(TABLE *const table,
+                   const MY_BITMAP *cols,
+                   uint width __attribute__((__unused__)),
+                   const bool check)
 {
 
   int error= 0;

=== modified file 'sql/scheduler.cc'
--- sql/scheduler.cc	2008-07-03 13:40:21 +0000
+++ sql/scheduler.cc	2008-07-09 15:52:52 +0000
@@ -31,9 +31,11 @@
  */
 
 static bool init_dummy(void) {return 0;}
-static void post_kill_dummy(THD *thd) {}  
+static void post_kill_dummy(THD *thd __attribute__((__unused__))) {}
 static void end_dummy(void) {}
-static bool end_thread_dummy(THD *thd, bool cache_thread) { return 0; }
+static bool end_thread_dummy(THD *thd __attribute__((__unused__)),
+                             bool cache_thread __attribute__((__unused__)))
+{ return 0; }
 
 /*
   Initialize default scheduler with dummy functions so that setup functions
@@ -483,7 +485,7 @@
   These procs only return/terminate on shutdown (kill_pool_threads == true).
 */
 
-pthread_handler_t libevent_thread_proc(void *arg)
+pthread_handler_t libevent_thread_proc(void *arg __attribute__((__unused__)))
 {
   if (init_new_connection_handler_thread())
   {

=== modified file 'sql/set_var.cc'
--- sql/set_var.cc	2008-07-09 12:31:20 +0000
+++ sql/set_var.cc	2008-07-09 15:52:52 +0000
@@ -97,7 +97,6 @@
 static int  check_log_update(THD *thd, set_var *var);
 static bool set_log_update(THD *thd, set_var *var);
 static int  check_pseudo_thread_id(THD *thd, set_var *var);
-void fix_binlog_format_after_update(THD *thd, enum_var_type type);
 static void fix_low_priority_updates(THD *thd, enum_var_type type);
 static int check_tx_isolation(THD *thd, set_var *var);
 static void fix_tx_isolation(THD *thd, enum_var_type type);
@@ -652,7 +651,7 @@
 };
 
 
-bool sys_var::check(THD *thd, set_var *var)
+bool sys_var::check(THD *thd __attribute__((__unused__)), set_var *var)
 {
   var->save_result.ulonglong_value= var->value->val_int();
   return 0;
@@ -706,25 +705,28 @@
 }
 
 
-static bool sys_update_init_connect(THD *thd, set_var *var)
+static bool sys_update_init_connect(THD *thd __attribute__((__unused__)), set_var *var)
 {
   return update_sys_var_str(&sys_init_connect, &LOCK_sys_init_connect, var);
 }
 
 
-static void sys_default_init_connect(THD* thd, enum_var_type type)
+static void sys_default_init_connect(THD* thd __attribute__((__unused__)),
+                                     enum_var_type type __attribute__((__unused__)))
 {
   update_sys_var_str(&sys_init_connect, &LOCK_sys_init_connect, 0);
 }
 
 
-static bool sys_update_init_slave(THD *thd, set_var *var)
+static bool sys_update_init_slave(THD *thd __attribute__((__unused__)),
+                                  set_var *var)
 {
   return update_sys_var_str(&sys_init_slave, &LOCK_sys_init_slave, var);
 }
 
 
-static void sys_default_init_slave(THD* thd, enum_var_type type)
+static void sys_default_init_slave(THD* thd __attribute__((__unused__)),
+                                   enum_var_type type __attribute__((__unused__)))
 {
   update_sys_var_str(&sys_init_slave, &LOCK_sys_init_slave, 0);
 }
@@ -748,7 +750,8 @@
 
 
 static void
-fix_myisam_max_sort_file_size(THD *thd, enum_var_type type)
+fix_myisam_max_sort_file_size(THD *thd __attribute__((__unused__)),
+                              enum_var_type type __attribute__((__unused__)))
 {
   myisam_max_temp_length=
     (my_off_t) global_system_variables.myisam_max_sort_file_size;
@@ -798,7 +801,8 @@
 static void fix_completion_type(THD *thd __attribute__((unused)),
 				enum_var_type type __attribute__((unused))) {}
 
-static int check_completion_type(THD *thd, set_var *var)
+static int check_completion_type(THD *thd __attribute__((__unused__)),
+                                 set_var *var)
 {
   longlong val= var->value->val_int();
   if (val < 0 || val > 2)
@@ -847,7 +851,8 @@
 #endif /* HAVE_REPLICATION */
 
 
-extern void fix_delay_key_write(THD *thd, enum_var_type type)
+extern void fix_delay_key_write(THD *thd __attribute__((__unused__)),
+                                enum_var_type type __attribute__((__unused__)))
 {
   switch ((enum_delay_key_write) delay_key_write_options) {
   case DELAY_KEY_WRITE_NONE:
@@ -863,14 +868,16 @@
   }
 }
 
-bool sys_var_set::update(THD *thd, set_var *var)
+bool sys_var_set::update(THD *thd __attribute__((__unused__)),
+                         set_var *var)
 {
   *value= var->save_result.ulong_value;
   return 0;
 }
 
-uchar *sys_var_set::value_ptr(THD *thd, enum_var_type type,
-                              LEX_STRING *base)
+uchar *sys_var_set::value_ptr(THD *thd,
+                              enum_var_type type __attribute__((__unused__)),
+                              LEX_STRING *base __attribute__((__unused__)))
 {
   char buff[256];
   String tmp(buff, sizeof(buff), &my_charset_latin1);
@@ -893,7 +900,8 @@
   return (uchar*) thd->strmake(tmp.ptr(), length);
 }
 
-void sys_var_set_slave_mode::set_default(THD *thd, enum_var_type type)
+void sys_var_set_slave_mode::set_default(THD *thd __attribute__((__unused__)),
+                                         enum_var_type type __attribute__((__unused__)))
 {
   slave_exec_mode_options= 0;
   bit_do_set(slave_exec_mode_options, SLAVE_EXEC_MODE_STRICT);
@@ -921,7 +929,7 @@
   return rc;
 }
 
-void fix_slave_exec_mode(enum_var_type type)
+void fix_slave_exec_mode(enum_var_type type __attribute__((__unused__)))
 {
   DBUG_ENTER("fix_slave_exec_mode");
   compile_time_assert(sizeof(slave_exec_mode_options) * CHAR_BIT
@@ -972,13 +980,15 @@
 }
 
 
-void fix_binlog_format_after_update(THD *thd, enum_var_type type)
+void fix_binlog_format_after_update(THD *thd,
+                                    enum_var_type type __attribute__((__unused__)))
 {
   thd->reset_current_stmt_binlog_row_based();
 }
 
 
-static void fix_max_binlog_size(THD *thd, enum_var_type type)
+static void fix_max_binlog_size(THD *thd __attribute__((__unused__)),
+                                enum_var_type type __attribute__((__unused__)))
 {
   DBUG_ENTER("fix_max_binlog_size");
   DBUG_PRINT("info",("max_binlog_size=%lu max_relay_log_size=%lu",
@@ -991,7 +1001,8 @@
   DBUG_VOID_RETURN;
 }
 
-static void fix_max_relay_log_size(THD *thd, enum_var_type type)
+static void fix_max_relay_log_size(THD *thd __attribute__((__unused__)),
+                                   enum_var_type type __attribute__((__unused__)))
 {
   DBUG_ENTER("fix_max_relay_log_size");
   DBUG_PRINT("info",("max_binlog_size=%lu max_relay_log_size=%lu",
@@ -1003,7 +1014,8 @@
   DBUG_VOID_RETURN;
 }
 
-static void fix_max_connections(THD *thd, enum_var_type type)
+static void fix_max_connections(THD *thd __attribute__((__unused__)),
+                                enum_var_type type __attribute__((__unused__)))
 {
   resize_thr_alarm(max_connections +  10);
 }
@@ -1027,7 +1039,8 @@
 }
 
 
-static void fix_server_id(THD *thd, enum_var_type type)
+static void fix_server_id(THD *thd __attribute__((__unused__)),
+                          enum_var_type type __attribute__((__unused__)))
 {
   server_id_supplied = 1;
   thd->server_id= server_id;
@@ -1063,7 +1076,7 @@
   return out;
 }
 
-static bool get_unsigned(THD *thd, set_var *var)
+static bool get_unsigned(THD *thd __attribute__((__unused__)), set_var *var)
 {
   if (var->value->unsigned_flag)
     var->save_result.ulonglong_value= (ulonglong) var->value->val_int();
@@ -1114,7 +1127,7 @@
 }
 
 
-void sys_var_long_ptr_global::set_default(THD *thd, enum_var_type type)
+void sys_var_long_ptr_global::set_default(THD *thd __attribute__((__unused__)), enum_var_type type __attribute__((__unused__)))
 {
   my_bool not_used;
   pthread_mutex_lock(guard);
@@ -1137,7 +1150,8 @@
 }
 
 
-void sys_var_ulonglong_ptr::set_default(THD *thd, enum_var_type type)
+void sys_var_ulonglong_ptr::set_default(THD *thd __attribute__((__unused__)),
+                                        enum_var_type type __attribute__((__unused__)))
 {
   my_bool not_used;
   pthread_mutex_lock(&LOCK_global_system_variables);
@@ -1147,34 +1161,37 @@
 }
 
 
-bool sys_var_bool_ptr::update(THD *thd, set_var *var)
+bool sys_var_bool_ptr::update(THD *thd __attribute__((__unused__)), set_var *var)
 {
   *value= (my_bool) var->save_result.ulong_value;
   return 0;
 }
 
 
-void sys_var_bool_ptr::set_default(THD *thd, enum_var_type type)
+void sys_var_bool_ptr::set_default(THD *thd __attribute__((__unused__)), enum_var_type type __attribute__((__unused__)))
 {
   *value= (my_bool) option_limits->def_value;
 }
 
 
-bool sys_var_enum::update(THD *thd, set_var *var)
+bool sys_var_enum::update(THD *thd __attribute__((__unused__)), set_var *var)
 {
   *value= (uint) var->save_result.ulong_value;
   return 0;
 }
 
 
-uchar *sys_var_enum::value_ptr(THD *thd, enum_var_type type, LEX_STRING *base)
+uchar *sys_var_enum::value_ptr(THD *thd __attribute__((__unused__)),
+                               enum_var_type type __attribute__((__unused__)),
+                               LEX_STRING *base __attribute__((__unused__)))
 {
   return (uchar*) enum_names->type_names[*value];
 }
 
 
-uchar *sys_var_enum_const::value_ptr(THD *thd, enum_var_type type,
-                                     LEX_STRING *base)
+uchar *sys_var_enum_const::value_ptr(THD *thd __attribute__((__unused__)),
+                                     enum_var_type type __attribute__((__unused__)),
+                                     LEX_STRING *base __attribute__((__unused__)))
 {
   return (uchar*) enum_names->type_names[global_system_variables.*offset];
 }
@@ -1188,14 +1205,14 @@
 bool sys_var_thd_ulong::update(THD *thd, set_var *var)
 {
   ulonglong tmp= var->save_result.ulonglong_value;
-
+  
   /* Don't use bigger value than given with --maximum-variable-name=.. */
   if ((ulong) tmp > max_system_variables.*offset)
   {
     throw_bounds_warning(thd, TRUE, TRUE, name, (longlong) tmp);
     tmp= max_system_variables.*offset;
   }
-
+  
   if (option_limits)
     tmp= (ulong) fix_unsigned(thd, tmp, option_limits);
 #if SIZEOF_LONG < SIZEOF_LONG_LONG
@@ -1205,33 +1222,33 @@
     throw_bounds_warning(thd, TRUE, TRUE, name, (longlong) var->save_result.ulonglong_value);
   }
 #endif
-
+  
   if (var->type == OPT_GLOBAL)
-    global_system_variables.*offset= (ulong) tmp;
-  else
-    thd->variables.*offset= (ulong) tmp;
-
-  return 0;
-}
-
-
-void sys_var_thd_ulong::set_default(THD *thd, enum_var_type type)
-{
-  if (type == OPT_GLOBAL)
-  {
-    my_bool not_used;
-    /* We will not come here if option_limits is not set */
-    global_system_variables.*offset=
-      (ulong) getopt_ull_limit_value((ulong) option_limits->def_value,
-                                     option_limits, &not_used);
-  }
-  else
-    thd->variables.*offset= global_system_variables.*offset;
-}
+     global_system_variables.*offset= (ulong) tmp;
+   else
+     thd->variables.*offset= (ulong) tmp;
+
+   return 0;
+ }
+
+
+ void sys_var_thd_ulong::set_default(THD *thd, enum_var_type type)
+ {
+   if (type == OPT_GLOBAL)
+   {
+     my_bool not_used;
+     /* We will not come here if option_limits is not set */
+     global_system_variables.*offset=
+       (ulong) getopt_ull_limit_value((ulong) option_limits->def_value,
+                                      option_limits, &not_used);
+   }
+   else
+     thd->variables.*offset= global_system_variables.*offset;
+ }
 
 
 uchar *sys_var_thd_ulong::value_ptr(THD *thd, enum_var_type type,
-				   LEX_STRING *base)
+                                    LEX_STRING *base __attribute__((__unused__)))
 {
   if (type == OPT_GLOBAL)
     return (uchar*) &(global_system_variables.*offset);
@@ -1280,7 +1297,7 @@
 
 
 uchar *sys_var_thd_ha_rows::value_ptr(THD *thd, enum_var_type type,
-				     LEX_STRING *base)
+                                      LEX_STRING *base __attribute__((__unused__)))
 {
   if (type == OPT_GLOBAL)
     return (uchar*) &(global_system_variables.*offset);
@@ -1331,7 +1348,7 @@
 
 
 uchar *sys_var_thd_ulonglong::value_ptr(THD *thd, enum_var_type type,
-				       LEX_STRING *base)
+                                        LEX_STRING *base __attribute__((__unused__)))
 {
   if (type == OPT_GLOBAL)
     return (uchar*) &(global_system_variables.*offset);
@@ -1359,7 +1376,7 @@
 
 
 uchar *sys_var_thd_bool::value_ptr(THD *thd, enum_var_type type,
-				  LEX_STRING *base)
+                                   LEX_STRING *base __attribute__((__unused__)))
 {
   if (type == OPT_GLOBAL)
     return (uchar*) &(global_system_variables.*offset);
@@ -1367,7 +1384,8 @@
 }
 
 
-bool sys_var::check_enum(THD *thd, set_var *var, const TYPELIB *enum_names)
+bool sys_var::check_enum(THD *thd __attribute__((__unused__)),
+                         set_var *var, const TYPELIB *enum_names)
 {
   char buff[STRING_BUFFER_USUAL_SIZE];
   const char *value;
@@ -1403,7 +1421,8 @@
 }
 
 
-bool sys_var::check_set(THD *thd, set_var *var, TYPELIB *enum_names)
+bool sys_var::check_set(THD *thd __attribute__((__unused__)),
+                        set_var *var, TYPELIB *enum_names)
 {
   bool not_used;
   char buff[STRING_BUFFER_USUAL_SIZE], *error= 0;
@@ -1602,7 +1621,7 @@
 
 
 uchar *sys_var_thd_enum::value_ptr(THD *thd, enum_var_type type,
-				  LEX_STRING *base)
+                                   LEX_STRING *base __attribute__((__unused__)))
 {
   ulong tmp= ((type == OPT_GLOBAL) ?
 	      global_system_variables.*offset :
@@ -1623,8 +1642,9 @@
 }
 
 
-uchar *sys_var_thd_bit::value_ptr(THD *thd, enum_var_type type,
-				 LEX_STRING *base)
+uchar *sys_var_thd_bit::value_ptr(THD *thd,
+                                  enum_var_type type __attribute__((__unused__)),
+                                  LEX_STRING *base __attribute__((__unused__)))
 {
   /*
     If reverse is 0 (default) return 1 if bit is set.
@@ -1724,7 +1744,7 @@
 
 
 uchar *sys_var_thd_date_time_format::value_ptr(THD *thd, enum_var_type type,
-					      LEX_STRING *base)
+                                               LEX_STRING *base __attribute__((__unused__)))
 {
   if (type == OPT_GLOBAL)
   {
@@ -1776,7 +1796,8 @@
 }
 
 
-bool sys_var_collation::check(THD *thd, set_var *var)
+bool sys_var_collation::check(THD *thd __attribute__((__unused__)),
+                              set_var *var)
 {
   CHARSET_INFO *tmp;
 
@@ -1810,7 +1831,8 @@
 }
 
 
-bool sys_var_character_set::check(THD *thd, set_var *var)
+bool sys_var_character_set::check(THD *thd __attribute__((__unused__)),
+                                  set_var *var)
 {
   CHARSET_INFO *tmp;
 
@@ -1858,7 +1880,7 @@
 
 
 uchar *sys_var_character_set::value_ptr(THD *thd, enum_var_type type,
-				       LEX_STRING *base)
+                                        LEX_STRING *base __attribute__((__unused__)))
 {
   CHARSET_INFO *cs= ci_ptr(thd,type)[0];
   return cs ? (uchar*) cs->csname : (uchar*) NULL;
@@ -1947,7 +1969,7 @@
 
 
 uchar *sys_var_collation_sv::value_ptr(THD *thd, enum_var_type type,
-                                       LEX_STRING *base)
+                                       LEX_STRING *base __attribute__((__unused__)))
 {
   CHARSET_INFO *cs= ((type == OPT_GLOBAL) ?
 		     global_system_variables.*offset : thd->variables.*offset);
@@ -1969,8 +1991,9 @@
 }
 
 
-uchar *sys_var_key_cache_param::value_ptr(THD *thd, enum_var_type type,
-					 LEX_STRING *base)
+uchar *sys_var_key_cache_param::value_ptr(THD *thd __attribute__((__unused__)),
+                                          enum_var_type type __attribute__((__unused__)),
+                                          LEX_STRING *base __attribute__((__unused__)))
 {
   KEY_CACHE *key_cache= get_key_cache(base);
   if (!key_cache)
@@ -2136,7 +2159,8 @@
   return res;
 }
 
-void sys_var_log_state::set_default(THD *thd, enum_var_type type)
+void sys_var_log_state::set_default(THD *thd,
+                                    enum_var_type type __attribute__((__unused__)))
 {
   pthread_mutex_lock(&LOCK_global_system_variables);
   logger.deactivate_log_handler(thd, log_type);
@@ -2144,7 +2168,8 @@
 }
 
 
-static int  sys_check_log_path(THD *thd,  set_var *var)
+static int  sys_check_log_path(THD *thd __attribute__((__unused__)),
+                               set_var *var)
 {
   char path[FN_REFLEN], buff[FN_REFLEN];
   struct stat f_stat;
@@ -2204,9 +2229,10 @@
 }
 
 
-bool update_sys_var_str_path(THD *thd, sys_var_str *var_str,
-			     set_var *var, const char *log_ext,
-			     bool log_state, uint log_type)
+bool update_sys_var_str_path(THD *thd __attribute__((__unused__)),
+                             sys_var_str *var_str,
+                             set_var *var, const char *log_ext,
+                             bool log_state, uint log_type)
 {
   MYSQL_QUERY_LOG *file_log;
   char buff[FN_REFLEN];
@@ -2269,35 +2295,38 @@
 
 static bool sys_update_general_log_path(THD *thd, set_var * var)
 {
-  return update_sys_var_str_path(thd, &sys_var_general_log_path, 
-				 var, ".log", opt_log, QUERY_LOG_GENERAL);
+  return update_sys_var_str_path(thd, &sys_var_general_log_path,
+                                 var, ".log", opt_log, QUERY_LOG_GENERAL);
 }
 
 
-static void sys_default_general_log_path(THD *thd, enum_var_type type)
+static void sys_default_general_log_path(THD *thd,
+                                         enum_var_type type __attribute__((__unused__)))
 {
   (void) update_sys_var_str_path(thd, &sys_var_general_log_path,
-				 0, ".log", opt_log, QUERY_LOG_GENERAL);
+                                 0, ".log", opt_log, QUERY_LOG_GENERAL);
 }
 
 
 static bool sys_update_slow_log_path(THD *thd, set_var * var)
 {
   return update_sys_var_str_path(thd, &sys_var_slow_log_path,
-				 var, "-slow.log", opt_slow_log,
+                                 var, "-slow.log", opt_slow_log,
                                  QUERY_LOG_SLOW);
 }
 
 
-static void sys_default_slow_log_path(THD *thd, enum_var_type type)
+static void sys_default_slow_log_path(THD *thd,
+                                      enum_var_type type __attribute__((__unused__)))
 {
   (void) update_sys_var_str_path(thd, &sys_var_slow_log_path,
-				 0, "-slow.log", opt_slow_log,
+                                 0, "-slow.log", opt_slow_log,
                                  QUERY_LOG_SLOW);
 }
 
 
-bool sys_var_log_output::update(THD *thd, set_var *var)
+bool sys_var_log_output::update(THD *thd __attribute__((__unused__)),
+                                set_var *var)
 {
   pthread_mutex_lock(&LOCK_global_system_variables);
   logger.lock_exclusive();
@@ -2310,7 +2339,8 @@
 }
 
 
-void sys_var_log_output::set_default(THD *thd, enum_var_type type)
+void sys_var_log_output::set_default(THD *thd __attribute__((__unused__)),
+                                     enum_var_type type __attribute__((__unused__)))
 {
   pthread_mutex_lock(&LOCK_global_system_variables);
   logger.lock_exclusive();
@@ -2322,8 +2352,9 @@
 }
 
 
-uchar *sys_var_log_output::value_ptr(THD *thd, enum_var_type type,
-                                    LEX_STRING *base)
+uchar *sys_var_log_output::value_ptr(THD *thd,
+                                     enum_var_type type __attribute__((__unused__)),
+                                     LEX_STRING *base __attribute__((__unused__)))
 {
   char buff[256];
   String tmp(buff, sizeof(buff), &my_charset_latin1);
@@ -2351,7 +2382,7 @@
   Functions to handle SET NAMES and SET CHARACTER SET
 *****************************************************************************/
 
-int set_var_collation_client::check(THD *thd)
+int set_var_collation_client::check(THD *thd __attribute__((__unused__)))
 {
   /* Currently, UCS-2 cannot be used as a client character set */
   if (character_set_client->mbminlen > 1)
@@ -2382,14 +2413,16 @@
 }
 
 
-void sys_var_timestamp::set_default(THD *thd, enum_var_type type)
+void sys_var_timestamp::set_default(THD *thd,
+                                    enum_var_type type __attribute__((__unused__)))
 {
   thd->user_time=0;
 }
 
 
-uchar *sys_var_timestamp::value_ptr(THD *thd, enum_var_type type,
-				   LEX_STRING *base)
+uchar *sys_var_timestamp::value_ptr(THD *thd,
+                                    enum_var_type type __attribute__((__unused__)),
+                                    LEX_STRING *base __attribute__((__unused__)))
 {
   thd->sys_var_tmp.long_value= (long) thd->start_time;
   return (uchar*) &thd->sys_var_tmp.long_value;
@@ -2398,17 +2431,18 @@
 
 bool sys_var_last_insert_id::update(THD *thd, set_var *var)
 {
-  thd->first_successful_insert_id_in_prev_stmt= 
+  thd->first_successful_insert_id_in_prev_stmt=
     var->save_result.ulonglong_value;
   return 0;
 }
 
 
-uchar *sys_var_last_insert_id::value_ptr(THD *thd, enum_var_type type,
-					LEX_STRING *base)
+uchar *sys_var_last_insert_id::value_ptr(THD *thd,
+                                         enum_var_type type __attribute__((__unused__)),
+                                         LEX_STRING *base __attribute__((__unused__)))
 {
   /*
-    this tmp var makes it robust againt change of type of 
+    this tmp var makes it robust againt change of type of
     read_first_successful_insert_id_in_prev_stmt().
   */
   thd->sys_var_tmp.ulonglong_value= 
@@ -2424,10 +2458,11 @@
 }
 
 
-uchar *sys_var_insert_id::value_ptr(THD *thd, enum_var_type type,
-				   LEX_STRING *base)
+uchar *sys_var_insert_id::value_ptr(THD *thd,
+                                    enum_var_type type __attribute__((__unused__)),
+                                    LEX_STRING *base __attribute__((__unused__)))
 {
-  thd->sys_var_tmp.ulonglong_value= 
+  thd->sys_var_tmp.ulonglong_value=
     thd->auto_inc_intervals_forced.minimum();
   return (uchar*) &thd->sys_var_tmp.ulonglong_value;
 }
@@ -2477,7 +2512,7 @@
 
 
 uchar *sys_var_thd_time_zone::value_ptr(THD *thd, enum_var_type type,
-				       LEX_STRING *base)
+                                        LEX_STRING *base __attribute__((__unused__)))
 {
   /* 
     We can use ptr() instead of c_ptr() here because String contaning
@@ -2539,7 +2574,8 @@
   }
 }
 
-bool sys_var_max_user_conn::update(THD *thd, set_var *var)
+bool sys_var_max_user_conn::update(THD *thd __attribute__((__unused__)),
+                                   set_var *var)
 {
   DBUG_ASSERT(var->type == OPT_GLOBAL);
   pthread_mutex_lock(&LOCK_global_system_variables);
@@ -2549,7 +2585,8 @@
 }
 
 
-void sys_var_max_user_conn::set_default(THD *thd, enum_var_type type)
+void sys_var_max_user_conn::set_default(THD *thd __attribute__((__unused__)),
+                                        enum_var_type type __attribute__((__unused__)))
 {
   DBUG_ASSERT(type == OPT_GLOBAL);
   pthread_mutex_lock(&LOCK_global_system_variables);
@@ -2559,7 +2596,7 @@
 
 
 uchar *sys_var_max_user_conn::value_ptr(THD *thd, enum_var_type type,
-                                       LEX_STRING *base)
+                                        LEX_STRING *base __attribute__((__unused__)))
 {
   if (type != OPT_GLOBAL &&
       thd->user_connect && thd->user_connect->user_resources.user_conn)
@@ -2568,7 +2605,8 @@
 }
 
 
-bool sys_var_thd_lc_time_names::check(THD *thd, set_var *var)
+bool sys_var_thd_lc_time_names::check(THD *thd __attribute__((__unused__)),
+                                      set_var *var)
 {
   MY_LOCALE *locale_match;
 
@@ -2615,8 +2653,9 @@
 }
 
 
-uchar *sys_var_thd_lc_time_names::value_ptr(THD *thd, enum_var_type type,
-					  LEX_STRING *base)
+uchar *sys_var_thd_lc_time_names::value_ptr(THD *thd,
+                                            enum_var_type type,
+                                            LEX_STRING *base __attribute__((__unused__)))
 {
   return type == OPT_GLOBAL ?
                  (uchar *) global_system_variables.lc_time_names->name :
@@ -2677,7 +2716,7 @@
 
 
 uchar *sys_var_microseconds::value_ptr(THD *thd, enum_var_type type,
-                                          LEX_STRING *base)
+                                          LEX_STRING *base __attribute__((__unused__)))
 {
   thd->tmp_double_value= (double) ((type == OPT_GLOBAL) ?
                                    global_system_variables.*offset :
@@ -2732,12 +2771,14 @@
   return 0;
 }
 
-static int check_log_update(THD *thd, set_var *var)
+static int check_log_update(THD *thd __attribute__((__unused__)),
+                            set_var *var __attribute__((__unused__)))
 {
   return 0;
 }
 
-static bool set_log_update(THD *thd, set_var *var)
+static bool set_log_update(THD *thd __attribute__((__unused__)),
+                           set_var *var __attribute__((__unused__)))
 {
   /*
     The update log is not supported anymore since 5.0.
@@ -2760,7 +2801,8 @@
 }
 
 
-static int check_pseudo_thread_id(THD *thd, set_var *var)
+static int check_pseudo_thread_id(THD *thd __attribute__((__unused__)),
+                                  set_var *var)
 {
   var->save_result.ulonglong_value= var->value->val_int();
   return 0;
@@ -2797,7 +2839,7 @@
   @retval
     ptr		pointer to NUL-terminated string
 */
-static uchar *get_tmpdir(THD *thd)
+static uchar *get_tmpdir(THD *thd __attribute__((__unused__)))
 {
   if (opt_mysql_tmpdir)
     return (uchar *)opt_mysql_tmpdir;
@@ -2848,7 +2890,7 @@
 */
 
 static uchar *get_sys_var_length(const sys_var *var, size_t *length,
-                                 my_bool first)
+                                 my_bool first __attribute__((__unused__)))
 {
   *length= var->name_length;
   return (uchar*) var->name;
@@ -3230,7 +3272,7 @@
 }
 
 
-int set_var_user::update(THD *thd)
+int set_var_user::update(THD *thd __attribute__((__unused__)))
 {
   if (user_var_item->update())
   {
@@ -3279,7 +3321,7 @@
 
 
 uchar *sys_var_thd_storage_engine::value_ptr(THD *thd, enum_var_type type,
-					    LEX_STRING *base)
+                                             LEX_STRING *base __attribute__((__unused__)))
 {
   uchar* result;
   handlerton *hton;
@@ -3361,7 +3403,7 @@
 
 
 uchar *sys_var_thd_optimizer_switch::value_ptr(THD *thd, enum_var_type type,
-				               LEX_STRING *base)
+                                               LEX_STRING *base __attribute__((__unused__)))
 {
   LEX_STRING opts;
   ulonglong val= ((type == OPT_GLOBAL) ? global_system_variables.*offset :
@@ -3464,7 +3506,8 @@
 }
 
 
-void free_key_cache(const char *name, KEY_CACHE *key_cache)
+void free_key_cache(const char *name __attribute__((__unused__)),
+                    KEY_CACHE *key_cache)
 {
   ha_end_key_cache(key_cache);
   my_free((char*) key_cache, MYF(0));
@@ -3548,7 +3591,8 @@
   DBUG_RETURN(result);
 }
 
-bool sys_var_thd_dbug::update(THD *thd, set_var *var)
+bool sys_var_thd_dbug::update(THD *thd __attribute__((__unused__)),
+                              set_var *var)
 {
   if (var->type == OPT_GLOBAL)
   {
@@ -3563,7 +3607,8 @@
 }
 
 
-uchar *sys_var_thd_dbug::value_ptr(THD *thd, enum_var_type type, LEX_STRING *b)
+uchar *sys_var_thd_dbug::value_ptr(THD *thd, enum_var_type type,
+                                   LEX_STRING *b __attribute__((__unused__)))
 {
   char buf[256];
   if (type == OPT_GLOBAL)

=== modified file 'sql/sql_base.cc'
--- sql/sql_base.cc	2008-07-07 12:48:50 +0000
+++ sql/sql_base.cc	2008-07-09 15:52:52 +0000
@@ -466,7 +466,8 @@
      that the table is deleted or the thread is killed.
 */
 
-void release_table_share(TABLE_SHARE *share, enum release_type type)
+void release_table_share(TABLE_SHARE *share,
+                         enum release_type type __attribute__((__unused__)))
 {
   bool to_be_deleted= 0;
   DBUG_ENTER("release_table_share");
@@ -609,7 +610,8 @@
     #		Pointer to list of names of open tables.
 */
 
-OPEN_TABLE_LIST *list_open_tables(THD *thd, const char *db, const char *wild)
+OPEN_TABLE_LIST *list_open_tables(THD *thd __attribute__((__unused__)),
+                                  const char *db, const char *wild)
 {
   int result = 0;
   OPEN_TABLE_LIST **start_list, *open_list;
@@ -1239,7 +1241,8 @@
 
 
 /* close_temporary_tables' internal, 4 is due to uint4korr definition */
-static inline uint  tmpkeyval(THD *thd, TABLE *table)
+static inline uint  tmpkeyval(THD *thd __attribute__((__unused__)),
+                              TABLE *table)
 {
   return uint4korr(table->s->table_cache_key.str + table->s->table_cache_key.length - 4);
 }
@@ -1532,8 +1535,8 @@
 */
 
 void update_non_unique_table_error(TABLE_LIST *update,
-                                   const char *operation,
-                                   TABLE_LIST *duplicate)
+                                   const char *operation __attribute__((__unused__)),
+                                   TABLE_LIST *duplicate __attribute__((__unused__)))
 {
   my_error(ER_UPDATE_TABLE_USED, MYF(0), update->alias);
 }
@@ -3297,7 +3300,8 @@
 static int open_unireg_entry(THD *thd, TABLE *entry, TABLE_LIST *table_list,
                              const char *alias,
                              char *cache_key, uint cache_key_length,
-                             MEM_ROOT *mem_root, uint flags)
+                             MEM_ROOT *mem_root __attribute__((__unused__)),
+                             uint flags __attribute__((__unused__)))
 {
   int error;
   TABLE_SHARE *share;
@@ -4318,9 +4322,10 @@
 
 static Field *
 find_field_in_view(THD *thd, TABLE_LIST *table_list,
-                   const char *name, uint length,
-                   const char *item_name, Item **ref,
-                   bool register_tree_change)
+                   const char *name, uint length __attribute__((__unused__)),
+                   const char *item_name __attribute__((__unused__)),
+                   Item **ref,
+                   bool register_tree_change __attribute__((__unused__)))
 {
   DBUG_ENTER("find_field_in_view");
   DBUG_PRINT("enter",
@@ -4398,7 +4403,8 @@
 
 static Field *
 find_field_in_natural_join(THD *thd, TABLE_LIST *table_ref, const char *name,
-                           uint length, Item **ref, bool register_tree_change,
+                           uint length __attribute__((__unused__)),
+                           Item **ref, bool register_tree_change,
                            TABLE_LIST **actual_table)
 {
   List_iterator_fast<Natural_join_column>
@@ -5595,7 +5601,8 @@
 */
 
 static bool
-store_natural_using_join_columns(THD *thd, TABLE_LIST *natural_using_join,
+store_natural_using_join_columns(THD *thd __attribute__((__unused__)),
+                                 TABLE_LIST *natural_using_join,
                                  TABLE_LIST *table_ref_1,
                                  TABLE_LIST *table_ref_2,
                                  List<String> *using_fields,
@@ -5926,9 +5933,11 @@
 ** Expand all '*' in given fields
 ****************************************************************************/
 
-int setup_wild(THD *thd, TABLE_LIST *tables, List<Item> &fields,
-	       List<Item> *sum_func_list,
-	       uint wild_num)
+int setup_wild(THD *thd,
+               TABLE_LIST *tables __attribute__((__unused__)),
+               List<Item> &fields,
+               List<Item> *sum_func_list,
+               uint wild_num)
 {
   if (!wild_num)
     return(0);
@@ -6265,8 +6274,8 @@
 
 bool
 insert_fields(THD *thd, Name_resolution_context *context, const char *db_name,
-	      const char *table_name, List_iterator<Item> *it,
-              bool any_privileges)
+              const char *table_name, List_iterator<Item> *it,
+              bool any_privileges __attribute__((__unused__)))
 {
   Field_iterator_table_ref field_iterator;
   bool found;
@@ -6416,7 +6425,8 @@
     false if all is OK
 */
 
-int setup_conds(THD *thd, TABLE_LIST *tables, TABLE_LIST *leaves,
+int setup_conds(THD *thd, TABLE_LIST *tables __attribute__((__unused__)),
+                TABLE_LIST *leaves,
                 COND **conds)
 {
   SELECT_LEX *select_lex= thd->lex->current_select;
@@ -6590,7 +6600,8 @@
 */
 
 bool
-fill_record(THD *thd, Field **ptr, List<Item> &values, bool ignore_errors)
+fill_record(THD *thd, Field **ptr, List<Item> &values,
+            bool ignore_errors __attribute__((__unused__)))
 {
   List_iterator_fast<Item> v(values);
   Item *value;

=== modified file 'sql/sql_class.cc'
--- sql/sql_class.cc	2008-07-09 07:05:02 +0000
+++ sql/sql_class.cc	2008-07-09 15:52:52 +0000
@@ -238,13 +238,13 @@
 
 
 extern "C"
-const char *set_thd_proc_info(THD *thd, const char *info, 
-                              const char *calling_function, 
-                              const char *calling_file, 
-                              const unsigned int calling_line)
+const char *set_thd_proc_info(THD *thd, const char *info,
+                              const char *calling_function __attribute__((__unused__)),
+                              const char *calling_file __attribute__((__unused__)),
+                              const unsigned int calling_line __attribute__((__unused__)))
 {
   const char *old_info= thd->proc_info;
-  DBUG_PRINT("proc_info", ("%s:%d  %s", calling_file, calling_line, 
+  DBUG_PRINT("proc_info", ("%s:%d  %s", calling_file, calling_line,
                            (info != NULL) ? info : "(null)"));
   thd->proc_info= info;
   return old_info;
@@ -440,7 +440,8 @@
 */
 
 void
-Diagnostics_area::set_error_status(THD *thd, uint sql_errno_arg,
+Diagnostics_area::set_error_status(THD *thd __attribute__((__unused__)),
+                                   uint sql_errno_arg,
                                    const char *message_arg)
 {
   /*
@@ -1312,9 +1313,15 @@
   Item **place;
   Item *old_value;
   /* Placement new was hidden by `new' in ilink (TODO: check): */
-  static void *operator new(size_t size, void *mem) { return mem; }
-  static void operator delete(void *ptr, size_t size) {}
-  static void operator delete(void *ptr, void *mem) { /* never called */ }
+  static void *operator new(size_t size __attribute__((__unused__)),
+                            void *mem)
+    { return mem; }
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              size_t size __attribute__((__unused__)))
+    {}
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              void *mem __attribute__((__unused__)))
+    { /* never called */ }
 };
 
 
@@ -2109,12 +2116,12 @@
      sortcmp(val1, val2, cache->collation.collation) < 0);
 }
 
-bool select_exists_subselect::send_data(List<Item> &items)
+bool select_exists_subselect::send_data(List<Item> &items __attribute__((__unused__)))
 {
   DBUG_ENTER("select_exists_subselect::send_data");
   Item_exists_subselect *it= (Item_exists_subselect *)item;
   if (unit->offset_limit_cnt)
-  {				          // Using limit offset,count
+  { // Using limit offset,count
     unit->offset_limit_cnt--;
     DBUG_RETURN(0);
   }

=== modified file 'sql/sql_connect.cc'
--- sql/sql_connect.cc	2008-06-25 05:29:13 +0000
+++ sql/sql_connect.cc	2008-07-09 15:52:52 +0000
@@ -80,8 +80,9 @@
 
 int
 check_user(THD *thd, enum enum_server_command command,
-	       const char *passwd, uint passwd_len, const char *db,
-	       bool check_count)
+           const char *passwd __attribute__((__unused__)),
+           uint passwd_len, const char *db,
+           bool check_count)
 {
   DBUG_ENTER("check_user");
   LEX_STRING db_str= { (char *) db, db ? strlen(db) : 0 };

=== modified file 'sql/sql_delete.cc'
--- sql/sql_delete.cc	2008-07-08 16:53:50 +0000
+++ sql/sql_delete.cc	2008-07-09 15:52:52 +0000
@@ -505,7 +505,8 @@
 
 
 int
-multi_delete::prepare(List<Item> &values, SELECT_LEX_UNIT *u)
+multi_delete::prepare(List<Item> &values __attribute__((__unused__)),
+                      SELECT_LEX_UNIT *u)
 {
   
   unit= u;
@@ -600,7 +601,7 @@
 }
 
 
-bool multi_delete::send_data(List<Item> &values)
+bool multi_delete::send_data(List<Item> &values __attribute__((__unused__)))
 {
   int secure_counter= delete_while_scanning ? -1 : 0;
   TABLE_LIST *del_table;

=== modified file 'sql/sql_insert.cc'
--- sql/sql_insert.cc	2008-07-04 15:38:09 +0000
+++ sql/sql_insert.cc	2008-07-09 15:52:52 +0000
@@ -64,7 +64,8 @@
 
 static int check_insert_fields(THD *thd, TABLE_LIST *table_list,
                                List<Item> &fields, List<Item> &values,
-                               bool check_unique, table_map *map)
+                               bool check_unique,
+                               table_map *map __attribute__((__unused__)))
 {
   TABLE *table= table_list->table;
 
@@ -160,7 +161,8 @@
 */
 
 static int check_update_fields(THD *thd, TABLE_LIST *insert_table_list,
-                               List<Item> &update_fields, table_map *map)
+                               List<Item> &update_fields,
+                               table_map *map __attribute__((__unused__)))
 {
   TABLE *table= insert_table_list->table;
   my_bool timestamp_mark= false;
@@ -203,9 +205,10 @@
 */
 
 static
-void upgrade_lock_type(THD *thd, thr_lock_type *lock_type,
+void upgrade_lock_type(THD *thd __attribute__((__unused__)),
+                       thr_lock_type *lock_type,
                        enum_duplicates duplic,
-                       bool is_multi_insert)
+                       bool is_multi_insert __attribute__((__unused__)))
 {
   if (duplic == DUP_UPDATE ||
       (duplic == DUP_REPLACE && *lock_type == TL_WRITE_CONCURRENT_INSERT))
@@ -582,7 +585,7 @@
 */
 
 static bool mysql_prepare_insert_check_table(THD *thd, TABLE_LIST *table_list,
-                                             List<Item> &fields,
+                                             List<Item> &fields __attribute__((__unused__)),
                                              bool select_insert)
 {
   
@@ -640,7 +643,8 @@
                           TABLE *table, List<Item> &fields, List_item *values,
                           List<Item> &update_fields, List<Item> &update_values,
                           enum_duplicates duplic,
-                          COND **where, bool select_insert,
+                          COND **where __attribute__((__unused__)),
+                          bool select_insert,
                           bool check_fields, bool abort_on_warning)
 {
   SELECT_LEX *select_lex= &thd->lex->select_lex;

=== modified file 'sql/sql_lex.h'
--- sql/sql_lex.h	2008-07-09 07:05:02 +0000
+++ sql/sql_lex.h	2008-07-09 15:52:52 +0000
@@ -1685,7 +1685,6 @@
 extern void lex_free(void);
 extern void lex_start(THD *thd);
 extern void lex_end(LEX *lex);
-extern int MYSQLlex(void *arg, void *yythd);
 
 extern void trim_whitespace(CHARSET_INFO *cs, LEX_STRING *str);
 

=== modified file 'sql/sql_parse.cc'
--- sql/sql_parse.cc	2008-07-08 20:52:20 +0000
+++ sql/sql_parse.cc	2008-07-09 15:52:52 +0000
@@ -3571,7 +3571,7 @@
     - 0, otherwise
 */
 
-TABLE_LIST *st_select_lex::end_nested_join(THD *thd)
+TABLE_LIST *st_select_lex::end_nested_join(THD *thd __attribute__((__unused__)))
 {
   TABLE_LIST *ptr;
   NESTED_JOIN *nested_join;
@@ -4070,7 +4070,8 @@
     This is written such that we have a short lock on LOCK_thread_count
 */
 
-uint kill_one_thread(THD *thd, ulong id, bool only_kill_query)
+uint kill_one_thread(THD *thd __attribute__((__unused__)),
+                     ulong id, bool only_kill_query)
 {
   THD *tmp;
   uint error=ER_NO_SUCH_THREAD;
@@ -4252,7 +4253,8 @@
     true  Error
 */
 
-bool multi_update_precheck(THD *thd, TABLE_LIST *tables)
+bool multi_update_precheck(THD *thd,
+                           TABLE_LIST *tables __attribute__((__unused__)))
 {
   const char *msg= 0;
   LEX *lex= thd->lex;
@@ -4289,7 +4291,8 @@
     true  error
 */
 
-bool multi_delete_precheck(THD *thd, TABLE_LIST *tables)
+bool multi_delete_precheck(THD *thd,
+                           TABLE_LIST *tables __attribute__((__unused__)))
 {
   SELECT_LEX *select_lex= &thd->lex->select_lex;
   TABLE_LIST **save_query_tables_own_last= thd->lex->query_tables_own_last;
@@ -4325,7 +4328,8 @@
   @return Matching table, NULL otherwise.
 */
 
-static TABLE_LIST *multi_delete_table_match(LEX *lex, TABLE_LIST *tbl,
+static TABLE_LIST *multi_delete_table_match(LEX *lex __attribute__((__unused__)),
+                                            TABLE_LIST *tbl,
                                             TABLE_LIST *tables)
 {
   TABLE_LIST *match= NULL;
@@ -4418,7 +4422,7 @@
     true  Error
 */
 
-bool update_precheck(THD *thd, TABLE_LIST *tables)
+bool update_precheck(THD *thd, TABLE_LIST *tables __attribute__((__unused__)))
 {
   DBUG_ENTER("update_precheck");
   if (thd->lex->select_lex.item_list.elements != thd->lex->value_list.elements)
@@ -4442,7 +4446,7 @@
     true   error
 */
 
-bool insert_precheck(THD *thd, TABLE_LIST *tables)
+bool insert_precheck(THD *thd, TABLE_LIST *tables __attribute__((__unused__)))
 {
   LEX *lex= thd->lex;
   DBUG_ENTER("insert_precheck");
@@ -4473,7 +4477,8 @@
     true   Error
 */
 
-bool create_table_precheck(THD *thd, TABLE_LIST *tables,
+bool create_table_precheck(THD *thd,
+                           TABLE_LIST *tables __attribute__((__unused__)),
                            TABLE_LIST *create_table)
 {
   LEX *lex= thd->lex;

=== modified file 'sql/sql_select.cc'
--- sql/sql_select.cc	2008-07-08 16:53:50 +0000
+++ sql/sql_select.cc	2008-07-09 15:52:52 +0000
@@ -169,7 +169,6 @@
 				 table_map used_table,
                                  bool exclude_expensive_cond);
 static Item* part_of_refkey(TABLE *form,Field *field);
-uint find_shortest_key(TABLE *table, const key_map *usable_keys);
 static bool test_if_skip_sort_order(JOIN_TAB *tab,ORDER *order,
 				    ha_rows select_limit, bool no_changes,
                                     const key_map *map);
@@ -4667,7 +4666,8 @@
 
 static bool
 update_ref_and_keys(THD *thd, DYNAMIC_ARRAY *keyuse,JOIN_TAB *join_tab,
-                    uint tables, COND *cond, COND_EQUAL *cond_equal,
+                    uint tables, COND *cond,
+                    COND_EQUAL *cond_equal __attribute__((__unused__)),
                     table_map normal_tables, SELECT_LEX *select_lex,
                     SARGABLE_PARAM **sargables)
 {
@@ -5019,7 +5019,7 @@
                  table_map remaining_tables,
                  uint      idx,
                  double    record_count,
-                 double    read_time)
+                 double    read_time __attribute__((__unused__)))
 {
   KEYUSE *best_key=         0;
   uint best_max_key_part=   0;
@@ -6369,7 +6369,8 @@
   Find how much space the prevous read not const tables takes in cache.
 */
 
-static void calc_used_field_length(THD *thd, JOIN_TAB *join_tab)
+static void calc_used_field_length(THD *thd __attribute__((__unused__)),
+                                   JOIN_TAB *join_tab)
 {
   uint null_fields,blobs,fields,rec_length;
   Field **f_ptr,*field;
@@ -10797,7 +10798,8 @@
     new_created field
 */
 
-static Field *create_tmp_field_from_item(THD *thd, Item *item, TABLE *table,
+static Field *create_tmp_field_from_item(THD *thd __attribute__((__unused__)),
+                                         Item *item, TABLE *table,
                                          Item ***copy_func, bool modify_item,
                                          uint convert_blob_length)
 {
@@ -10920,7 +10922,8 @@
     new_created field
 */
 
-Field *create_tmp_field_for_schema(THD *thd, Item *item, TABLE *table)
+Field *create_tmp_field_for_schema(THD *thd __attribute__((__unused__)),
+                                   Item *item, TABLE *table)
 {
   if (item->field_type() == MYSQL_TYPE_VARCHAR)
   {
@@ -10973,7 +10976,7 @@
                         Item ***copy_func, Field **from_field,
                         Field **default_field,
                         bool group, bool modify_item,
-                        bool table_cant_handle_bit_fields,
+                        bool table_cant_handle_bit_fields __attribute__((__unused__)),
                         bool make_copy_field,
                         uint convert_blob_length)
 {
@@ -16531,11 +16534,11 @@
 static ORDER *
 create_distinct_group(THD *thd, Item **ref_pointer_array,
                       ORDER *order_list, List<Item> &fields,
-                      List<Item> &all_fields,
-		      bool *all_order_by_fields_used)
+                      List<Item> &all_fields __attribute__((__unused__)),
+                      bool *all_order_by_fields_used)
 {
   List_iterator<Item> li(fields);
-  Item *item, **orig_ref_pointer_array= ref_pointer_array;
+  Item *item;
   ORDER *order,*group,**prev;
 
   *all_order_by_fields_used= 1;
@@ -17436,7 +17439,8 @@
   @param select   pointer to st_select_lex which subselects joins we will free
 */
 
-void free_underlaid_joins(THD *thd, SELECT_LEX *select)
+void free_underlaid_joins(THD *thd __attribute__((__unused__)),
+                          SELECT_LEX *select)
 {
   for (SELECT_LEX_UNIT *unit= select->first_inner_unit();
        unit;
@@ -18469,7 +18473,7 @@
 static void print_join(THD *thd,
                        String *str,
                        List<TABLE_LIST> *tables,
-                       enum_query_type query_type)
+                       enum_query_type query_type __attribute__((__unused__)))
 {
   /* List is reversed => we should reverse it before using */
   List_iterator_fast<TABLE_LIST> ti(*tables);

=== modified file 'sql/sql_show.cc'
--- sql/sql_show.cc	2008-07-08 20:23:17 +0000
+++ sql/sql_show.cc	2008-07-09 15:52:52 +0000
@@ -1526,7 +1526,7 @@
       Repeat as necessary, if new var is again SHOW_FUNC
     */
     for (var=variables; var->type == SHOW_FUNC; var= &tmp)
-      ((mysql_show_var_func)(var->value))(thd, &tmp, buff);
+      ((mysql_show_var_func)((st_show_var_func_container)var->value)->func)(thd, &tmp, buff);
 
     SHOW_TYPE show_type=var->type;
     if (show_type == SHOW_ARRAY)

=== modified file 'sql/sql_update.cc'
--- sql/sql_update.cc	2008-07-08 16:58:38 +0000
+++ sql/sql_update.cc	2008-07-09 15:52:52 +0000
@@ -173,11 +173,12 @@
 int mysql_update(THD *thd,
                  TABLE_LIST *table_list,
                  List<Item> &fields,
-		 List<Item> &values,
+                 List<Item> &values,
                  COND *conds,
                  uint order_num, ORDER *order,
-		 ha_rows limit,
-		 enum enum_duplicates handle_duplicates, bool ignore)
+                 ha_rows limit,
+                 enum enum_duplicates handle_duplicates __attribute__((__unused__)),
+                 bool ignore)
 {
   bool		using_limit= limit != HA_POS_ERROR;
   bool		safe_update= test(thd->options & OPTION_SAFE_UPDATES);
@@ -1046,8 +1047,8 @@
   Connect fields with tables and create list of tables that are updated
 */
 
-int multi_update::prepare(List<Item> &not_used_values,
-			  SELECT_LEX_UNIT *lex_unit)
+int multi_update::prepare(List<Item> &not_used_values __attribute__((__unused__)),
+                          SELECT_LEX_UNIT *lex_unit __attribute__((__unused__)))
 {
   TABLE_LIST *table_ref;
   SQL_LIST update;
@@ -1335,12 +1336,12 @@
   if (copy_field)
     delete [] copy_field;
   thd->count_cuted_fields= CHECK_FIELD_IGNORE;		// Restore this setting
-  assert(trans_safe || !updated || 
+  assert(trans_safe || !updated ||
               thd->transaction.all.modified_non_trans_table);
 }
 
 
-bool multi_update::send_data(List<Item> &not_used_values)
+bool multi_update::send_data(List<Item> &not_used_values __attribute__((__unused__)))
 {
   TABLE_LIST *cur_table;
   

=== modified file 'sql/sql_yacc.yy'
--- sql/sql_yacc.yy	2008-07-09 13:07:14 +0000
+++ sql/sql_yacc.yy	2008-07-09 15:52:52 +0000
@@ -29,6 +29,9 @@
 #define YYLEX_PARAM yythd
 #define YYTHD ((THD *)yythd)
 
+#define YYENABLE_NLS 0
+#define YYLTYPE_IS_TRIVIAL 0
+
 #define MYSQL_YACC
 #define YYINITDEPTH 100
 #define YYMAXDEPTH 3200                        /* Because of 64K stack */

=== modified file 'sql/table.cc'
--- sql/table.cc	2008-07-09 07:05:02 +0000
+++ sql/table.cc	2008-07-09 15:52:52 +0000
@@ -2228,7 +2228,8 @@
     given a buffer with a key value, and a map of keyparts
     that are present in this value, returns the length of the value
 */
-uint calculate_key_len(TABLE *table, uint key, const uchar *buf,
+uint calculate_key_len(TABLE *table, uint key,
+                       const uchar *buf __attribute__((__unused__)),
                        key_part_map keypart_map)
 {
   /* works only with key prefixes */
@@ -2902,8 +2903,9 @@
   return create_view_field(thd, view, &ptr->item, ptr->name);
 }
 
-Item *create_view_field(THD *thd, TABLE_LIST *view, Item **field_ref,
-                        const char *name)
+Item *create_view_field(THD *thd __attribute__((__unused__)),
+                        TABLE_LIST *view, Item **field_ref,
+                        const char *name __attribute__((__unused__)))
 {
   if (view->schema_table_reformed)
   {
@@ -3658,12 +3660,13 @@
   path        path to file
 
   RETURN
-  FRMTYPE_ERROR       error                
-  FRMTYPE_TABLE       table                
- */    
+  FRMTYPE_ERROR       error
+  FRMTYPE_TABLE       table
+*/
 
-frm_type_enum mysql_frm_type(THD *thd, char *path, enum legacy_db_type *dbt)
-{   
+frm_type_enum mysql_frm_type(THD *thd __attribute__((__unused__)),
+                             char *path, enum legacy_db_type *dbt)
+{
   File file;
   uchar header[10];     /* This should be optimized */
   int error;

=== modified file 'sql/uniques.cc'
--- sql/uniques.cc	2008-07-03 02:53:22 +0000
+++ sql/uniques.cc	2008-07-09 15:52:52 +0000
@@ -34,7 +34,9 @@
 #include "sql_sort.h"
 
 
-int unique_write_to_file(uchar* key, element_count count, Unique *unique)
+int unique_write_to_file(uchar* key,
+                         element_count count __attribute__((__unused__)),
+                         Unique *unique)
 {
   /*
     Use unique->size (size of element stored in the tree) and not
@@ -45,7 +47,9 @@
   return my_b_write(&unique->file, key, unique->size) ? 1 : 0;
 }
 
-int unique_write_to_ptrs(uchar* key, element_count count, Unique *unique)
+int unique_write_to_ptrs(uchar* key,
+                         element_count count __attribute__((__unused__)),
+                         Unique *unique)
 {
   memcpy(unique->record_pointers, key, unique->size);
   unique->record_pointers+=unique->size;
@@ -122,7 +126,8 @@
       total_buf_elems* log2(n_buffers) / TIME_FOR_COMPARE_ROWID;
 */
 
-static double get_merge_buffers_cost(uint *buff_elems, uint elem_size,
+static double get_merge_buffers_cost(uint *buff_elems __attribute__((__unused__)),
+                                     uint elem_size,
                                      uint *first, uint *last)
 {
   uint total_buf_elems= 0;

=== modified file 'sql/unireg.cc'
--- sql/unireg.cc	2008-07-09 01:20:21 +0000
+++ sql/unireg.cc	2008-07-09 15:52:52 +0000
@@ -558,17 +558,18 @@
 } /* pack_keys */
 
 
-	/* Make formheader */
+/* Make formheader */
 
-static bool pack_header(uchar *forminfo, enum legacy_db_type table_type,
-			List<Create_field> &create_fields,
+static bool pack_header(uchar *forminfo,
+                        enum legacy_db_type table_type __attribute__((__unused__)),
+                        List<Create_field> &create_fields,
                         uint info_length, uint screens, uint table_options,
                         ulong data_offset, handler *file)
 {
   uint length,int_count,int_length,no_empty, int_parts;
   uint time_stamp_pos,null_fields;
   ulong reclength, totlength, n_length, com_length;
-  
+
 
   if (create_fields.elements > MAX_FIELDS)
   {
@@ -878,12 +879,13 @@
 }
 
 
-	/* save an empty record on start of formfile */
+/* save an empty record on start of formfile */
 
-static bool make_empty_rec(THD *thd, File file,enum legacy_db_type table_type,
-			   uint table_options,
-			   List<Create_field> &create_fields,
-			   uint reclength,
+static bool make_empty_rec(THD *thd, File file,
+                           enum legacy_db_type table_type __attribute__((__unused__)),
+                           uint table_options,
+                           List<Create_field> &create_fields,
+                           uint reclength,
                            ulong data_offset,
                            handler *handler)
 {

